@@ -78,7 +78,7 @@ void Speedo::changeEvent(QEvent *e)
 
 void Speedo::on_pushButton_clicked()
 {
-    trip=0;
+    trip=0;seconds=0;
 }
 void Speedo::start_gps()
 {
